@@ -2,8 +2,8 @@ import typing
 
 import os
 
-from mitmproxy.utils import human
-from mitmproxy import ctx
+from mitmproxy.utils import emoji
+from mitmproxy import ctx, hooks
 from mitmproxy import exceptions
 from mitmproxy import command
 from mitmproxy import flow
@@ -19,45 +19,12 @@ LISTEN_PORT = 8080
 
 
 class Core:
-    def load(self, loader):
-        loader.add_option(
-            "body_size_limit", typing.Optional[str], None,
-            """
-            Byte size limit of HTTP request and response bodies. Understands
-            k/m/g suffixes, i.e. 3m for 3 megabytes.
-            """
-        )
-        loader.add_option(
-            "keep_host_header", bool, False,
-            """
-            Reverse Proxy: Keep the original host header instead of rewriting it
-            to the reverse proxy target.
-            """
-        )
-
     def configure(self, updated):
         opts = ctx.options
         if opts.add_upstream_certs_to_client_chain and not opts.upstream_cert:
             raise exceptions.OptionsError(
-                "The no-upstream-cert and add-upstream-certs-to-client-chain "
-                "options are mutually exclusive. If no-upstream-cert is enabled "
-                "then the upstream certificate is not retrieved before generating "
-                "the client certificate chain."
+                "add_upstream_certs_to_client_chain requires the upstream_cert option to be enabled."
             )
-        if opts.add_upstream_certs_to_client_chain and not opts.ssl_insecure:
-            raise exceptions.OptionsError(
-                "The verify-upstream-cert requires certificate verification to be disabled. "
-                "If upstream certificates are verified then extra upstream certificates are "
-                "not available for inclusion to the client chain."
-            )
-        if "body_size_limit" in updated:
-            try:
-                human.parse_size(opts.body_size_limit)
-            except ValueError:
-                raise exceptions.OptionsError(
-                    "Invalid body size limit specification: %s" %
-                    opts.body_size_limit
-                )
         if "mode" in updated:
             mode = opts.mode
             if mode.startswith("reverse:") or mode.startswith("upstream:"):
@@ -79,7 +46,7 @@ class Core:
                 client_certs = os.path.expanduser(opts.client_certs)
                 if not os.path.exists(client_certs):
                     raise exceptions.OptionsError(
-                        "Client certificate path does not exist: {}".format(opts.client_certs)
+                        f"Client certificate path does not exist: {opts.client_certs}"
                     )
 
     @command.command("set")
@@ -89,6 +56,8 @@ class Core:
             strings and integers are set to None (if permitted), and sequences
             are emptied. Boolean values can be true, false or toggle.
             Multiple values are concatenated with a single space.
+            Sequences are set using multiple invocations to set for
+            the same option.
         """
         strspec = f"{option}={value}"
         try:
@@ -104,20 +73,22 @@ class Core:
         intercepted = [i for i in flows if i.intercepted]
         for f in intercepted:
             f.resume()
-        ctx.master.addons.trigger("update", intercepted)
+        ctx.master.addons.trigger(hooks.UpdateHook(intercepted))
 
     # FIXME: this will become view.mark later
     @command.command("flow.mark")
-    def mark(self, flows: typing.Sequence[flow.Flow], boolean: bool) -> None:
+    def mark(self, flows: typing.Sequence[flow.Flow], marker: mitmproxy.types.Marker) -> None:
         """
             Mark flows.
         """
         updated = []
+        if marker not in emoji.emoji:
+            raise exceptions.CommandError(f"invalid marker value")
+
         for i in flows:
-            if i.marked != boolean:
-                i.marked = boolean
-                updated.append(i)
-        ctx.master.addons.trigger("update", updated)
+            i.marked = marker
+            updated.append(i)
+        ctx.master.addons.trigger(hooks.UpdateHook(updated))
 
     # FIXME: this will become view.mark.toggle later
     @command.command("flow.mark.toggle")
@@ -126,8 +97,11 @@ class Core:
             Toggle mark for flows.
         """
         for i in flows:
-            i.marked = not i.marked
-        ctx.master.addons.trigger("update", flows)
+            if i.marked:
+                i.marked = ""
+            else:
+                i.marked = ":default:"
+        ctx.master.addons.trigger(hooks.UpdateHook(flows))
 
     @command.command("flow.kill")
     def kill(self, flows: typing.Sequence[flow.Flow]) -> None:
@@ -140,7 +114,7 @@ class Core:
                 f.kill()
                 updated.append(f)
         ctx.log.alert("Killed %s flows." % len(updated))
-        ctx.master.addons.trigger("update", updated)
+        ctx.master.addons.trigger(hooks.UpdateHook(updated))
 
     # FIXME: this will become view.revert later
     @command.command("flow.revert")
@@ -154,7 +128,7 @@ class Core:
                 f.revert()
                 updated.append(f)
         ctx.log.alert("Reverted %s flows." % len(updated))
-        ctx.master.addons.trigger("update", updated)
+        ctx.master.addons.trigger(hooks.UpdateHook(updated))
 
     @command.command("flow.set.options")
     def flow_set_options(self) -> typing.Sequence[str]:
@@ -203,7 +177,7 @@ class Core:
                         req.url = val
                     except ValueError as e:
                         raise exceptions.CommandError(
-                            "URL %s is invalid: %s" % (repr(val), e)
+                            "URL {} is invalid: {}".format(repr(val), e)
                         ) from e
                 else:
                     self.rupdate = False
@@ -223,8 +197,8 @@ class Core:
             if rupdate or supdate:
                 updated.append(f)
 
-        ctx.master.addons.trigger("update", updated)
-        ctx.log.alert("Set %s on  %s flows." % (attr, len(updated)))
+        ctx.master.addons.trigger(hooks.UpdateHook(updated))
+        ctx.log.alert("Set {} on  {} flows.".format(attr, len(updated)))
 
     @command.command("flow.decode")
     def decode(self, flows: typing.Sequence[flow.Flow], part: str) -> None:
@@ -238,7 +212,7 @@ class Core:
                 f.backup()
                 p.decode()
                 updated.append(f)
-        ctx.master.addons.trigger("update", updated)
+        ctx.master.addons.trigger(hooks.UpdateHook(updated))
         ctx.log.alert("Decoded %s flows." % len(updated))
 
     @command.command("flow.encode.toggle")
@@ -257,7 +231,7 @@ class Core:
                 else:
                     p.decode()
                 updated.append(f)
-        ctx.master.addons.trigger("update", updated)
+        ctx.master.addons.trigger(hooks.UpdateHook(updated))
         ctx.log.alert("Toggled encoding on %s flows." % len(updated))
 
     @command.command("flow.encode")
@@ -280,7 +254,7 @@ class Core:
                     f.backup()
                     p.encode(encoding)
                     updated.append(f)
-        ctx.master.addons.trigger("update", updated)
+        ctx.master.addons.trigger(hooks.UpdateHook(updated))
         ctx.log.alert("Encoded %s flows." % len(updated))
 
     @command.command("flow.encode.options")
