@@ -31,12 +31,14 @@ class ModifyBody:
                 self.replacements.append(spec)
 
     def request(self, flow):
-        if not flow.reply.has_message:
-            self.run(flow)
+        if flow.response or flow.error or flow.reply.state == "taken":
+            return
+        self.run(flow)
 
     def response(self, flow):
-        if not flow.reply.has_message:
-            self.run(flow)
+        if flow.error or flow.reply.state == "taken":
+            return
+        self.run(flow)
 
     def run(self, flow):
         for spec in self.replacements:
