@@ -15,13 +15,14 @@ import blinker
 import sortedcontainers
 
 import mitmproxy.flow
-from mitmproxy import flowfilter
-from mitmproxy import exceptions
 from mitmproxy import command
-from mitmproxy import connections
 from mitmproxy import ctx
-from mitmproxy import io
+from mitmproxy import exceptions
+from mitmproxy import hooks
+from mitmproxy import connection
+from mitmproxy import flowfilter
 from mitmproxy import http
+from mitmproxy import io
 from mitmproxy import tcp
 from mitmproxy.utils import human
 
@@ -133,15 +134,15 @@ class View(collections.abc.Sequence):
 
         self.default_order = OrderRequestStart(self)
         self.orders = dict(
-            time = OrderRequestStart(self), method = OrderRequestMethod(self),
-            url = OrderRequestURL(self), size = OrderKeySize(self),
+            time=OrderRequestStart(self), method=OrderRequestMethod(self),
+            url=OrderRequestURL(self), size=OrderKeySize(self),
         )
         self.order_key = self.default_order
         self.order_reversed = False
         self.focus_follow = False
 
         self._view = sortedcontainers.SortedListWithKey(
-            key = self.order_key
+            key=self.order_key
         )
 
         # The sig_view* signals broadcast events that affect the view. That is,
@@ -381,7 +382,7 @@ class View(collections.abc.Sequence):
             current = self.settings[f].get("key", "false")
             self.settings[f][key] = "false" if current == "true" else "true"
             updated.append(f)
-        ctx.master.addons.trigger("update", updated)
+        ctx.master.addons.trigger(hooks.UpdateHook(updated))
 
     @command.command("view.settings.setval")
     def setvalue(
@@ -396,7 +397,7 @@ class View(collections.abc.Sequence):
         for f in flows:
             self.settings[f][key] = value
             updated.append(f)
-        ctx.master.addons.trigger("update", updated)
+        ctx.master.addons.trigger(hooks.UpdateHook(updated))
 
     # Flows
     @command.command("view.flows.duplicate")
@@ -457,11 +458,13 @@ class View(collections.abc.Sequence):
     @command.command("view.flows.create")
     def create(self, method: str, url: str) -> None:
         try:
-            req = http.HTTPRequest.make(method.upper(), url)
+            req = http.Request.make(method.upper(), url)
         except ValueError as e:
             raise exceptions.CommandError("Invalid URL: %s" % e)
-        c = connections.ClientConnection.make_dummy(("", 0))
-        s = connections.ServerConnection.make_dummy((req.host, req.port))
+
+        c = connection.Client(("", 0), ("", 0), req.timestamp_start - 0.0001)
+        s = connection.Server((req.host, req.port))
+
         f = http.HTTPFlow(c, s)
         f.request = req
         f.request.headers["Host"] = req.host
@@ -479,7 +482,7 @@ class View(collections.abc.Sequence):
                     # get new flows each time. It would be more efficient to just have a
                     # .newid() method or something.
                     self.add([i.copy()])
-        except IOError as e:
+        except OSError as e:
             ctx.log.error(e.strerror)
         except exceptions.FlowReadException as e:
             ctx.log.error(str(e))
@@ -620,6 +623,7 @@ class Focus:
     """
         Tracks a focus element within a View.
     """
+
     def __init__(self, v: View) -> None:
         self.view = v
         self._flow: typing.Optional[mitmproxy.flow.Flow] = None
