@@ -1,10 +1,10 @@
 import io
 import re
 import textwrap
-from typing import Iterable
+from typing import Iterable, Optional
 
 from mitmproxy.contentviews import base
-from mitmproxy.utils import sliding_window
+from mitmproxy.utils import sliding_window, strutils
 
 """
 A custom XML/HTML prettifier. Compared to other prettifiers, its main features are:
@@ -18,7 +18,7 @@ The implementation is split into two main parts: tokenization and formatting of
 """
 
 # http://www.xml.com/pub/a/2001/07/25/namingparts.html - this is close enough for what we do.
-REGEX_TAG = re.compile("[a-zA-Z0-9._:\-]+(?!=)")
+REGEX_TAG = re.compile(r"[a-zA-Z0-9._:\-]+(?!=)")
 # https://www.w3.org/TR/html5/syntax.html#void-elements
 HTML_VOID_ELEMENTS = {
     "area", "base", "br", "col", "embed", "hr", "img", "input", "keygen", "link", "meta", "param",
@@ -124,21 +124,21 @@ def indent_text(data: str, prefix: str) -> str:
     return textwrap.indent(dedented, prefix[:32])
 
 
-def is_inline_text(a: Token, b: Token, c: Token) -> bool:
+def is_inline_text(a: Optional[Token], b: Optional[Token], c: Optional[Token]) -> bool:
     if isinstance(a, Tag) and isinstance(b, Text) and isinstance(c, Tag):
         if a.is_opening and "\n" not in b.data and c.is_closing and a.tag == c.tag:
             return True
     return False
 
 
-def is_inline(prev2: Token, prev1: Token, t: Token, next1: Token, next2: Token) -> bool:
+def is_inline(prev2: Optional[Token], prev1: Optional[Token], t: Optional[Token], next1: Optional[Token], next2: Optional[Token]) -> bool:
     if isinstance(t, Text):
         return is_inline_text(prev1, t, next1)
     elif isinstance(t, Tag):
         if is_inline_text(prev2, prev1, t) or is_inline_text(t, next1, next2):
             return True
         if isinstance(next1, Tag) and t.is_opening and next1.is_closing and t.tag == next1.tag:
-                return True  # <div></div> (start tag)
+            return True  # <div></div> (start tag)
         if isinstance(prev1, Tag) and prev1.is_opening and t.is_closing and prev1.tag == t.tag:
             return True  # <div></div> (end tag)
     return False
@@ -214,7 +214,7 @@ def format_xml(tokens: Iterable[Token]) -> str:
 
 class ViewXmlHtml(base.View):
     name = "XML/HTML"
-    content_types = ["text/xml", "text/html"]
+    __content_types = ("text/xml", "text/html")
 
     def __call__(self, data, **metadata):
         # TODO:
@@ -233,3 +233,10 @@ class ViewXmlHtml(base.View):
         else:
             t = "XML"
         return t, pretty
+
+    def render_priority(self, data: bytes, *, content_type: Optional[str] = None, **metadata) -> float:
+        if content_type in self.__content_types:
+            return 1
+        elif strutils.is_xml(data):
+            return 0.4
+        return float(content_type in self.__content_types)
