@@ -36,13 +36,9 @@ import functools
 import re
 import sys
 from typing import Callable, ClassVar, Optional, Sequence, Type
-
 import pyparsing as pp
 
-from mitmproxy import flow
-from mitmproxy import http
-from mitmproxy import tcp
-from mitmproxy import websocket
+from mitmproxy import flow, http, tcp
 
 
 def only(*types):
@@ -90,7 +86,7 @@ class FMarked(_Action):
     help = "Match marked flows"
 
     def __call__(self, f):
-        return f.marked
+        return bool(f.marked)
 
 
 class FHTTP(_Action):
@@ -106,9 +102,9 @@ class FWebSocket(_Action):
     code = "websocket"
     help = "Match WebSocket flows"
 
-    @only(websocket.WebSocketFlow)
-    def __call__(self, f):
-        return True
+    @only(http.HTTPFlow)
+    def __call__(self, f: http.HTTPFlow):
+        return f.websocket is not None
 
 
 class FTCP(_Action):
@@ -163,14 +159,13 @@ def _check_content_type(rex, message):
 
 class FAsset(_Action):
     code = "a"
-    help = "Match asset in response: CSS, Javascript, Flash, images."
+    help = "Match asset in response: CSS, JavaScript, images."
     ASSET_TYPES = [re.compile(x) for x in [
         b"text/javascript",
         b"application/x-javascript",
         b"application/javascript",
         b"text/css",
-        b"image/.*",
-        b"application/x-shockwave-flash"
+        b"image/.*"
     ]]
 
     @only(http.HTTPFlow)
@@ -256,7 +251,7 @@ class FBod(_Rex):
     help = "Body"
     flags = re.DOTALL
 
-    @only(http.HTTPFlow, websocket.WebSocketFlow, tcp.TCPFlow)
+    @only(http.HTTPFlow, tcp.TCPFlow)
     def __call__(self, f):
         if isinstance(f, http.HTTPFlow):
             if f.request and f.request.raw_content:
@@ -265,7 +260,11 @@ class FBod(_Rex):
             if f.response and f.response.raw_content:
                 if self.re.search(f.response.get_content(strict=False)):
                     return True
-        elif isinstance(f, websocket.WebSocketFlow) or isinstance(f, tcp.TCPFlow):
+            if f.websocket:
+                for msg in f.websocket.messages:
+                    if self.re.search(msg.content):
+                        return True
+        elif isinstance(f, tcp.TCPFlow):
             for msg in f.messages:
                 if self.re.search(msg.content):
                     return True
@@ -277,13 +276,17 @@ class FBodRequest(_Rex):
     help = "Request body"
     flags = re.DOTALL
 
-    @only(http.HTTPFlow, websocket.WebSocketFlow, tcp.TCPFlow)
+    @only(http.HTTPFlow, tcp.TCPFlow)
     def __call__(self, f):
         if isinstance(f, http.HTTPFlow):
             if f.request and f.request.raw_content:
                 if self.re.search(f.request.get_content(strict=False)):
                     return True
-        elif isinstance(f, websocket.WebSocketFlow) or isinstance(f, tcp.TCPFlow):
+            if f.websocket:
+                for msg in f.websocket.messages:
+                    if msg.from_client and self.re.search(msg.content):
+                        return True
+        elif isinstance(f, tcp.TCPFlow):
             for msg in f.messages:
                 if msg.from_client and self.re.search(msg.content):
                     return True
@@ -294,13 +297,17 @@ class FBodResponse(_Rex):
     help = "Response body"
     flags = re.DOTALL
 
-    @only(http.HTTPFlow, websocket.WebSocketFlow, tcp.TCPFlow)
+    @only(http.HTTPFlow, tcp.TCPFlow)
     def __call__(self, f):
         if isinstance(f, http.HTTPFlow):
             if f.response and f.response.raw_content:
                 if self.re.search(f.response.get_content(strict=False)):
                     return True
-        elif isinstance(f, websocket.WebSocketFlow) or isinstance(f, tcp.TCPFlow):
+            if f.websocket:
+                for msg in f.websocket.messages:
+                    if not msg.from_client and self.re.search(msg.content):
+                        return True
+        elif isinstance(f, tcp.TCPFlow):
             for msg in f.messages:
                 if not msg.from_client and self.re.search(msg.content):
                     return True
@@ -322,10 +329,8 @@ class FDomain(_Rex):
     flags = re.IGNORECASE
     is_binary = False
 
-    @only(http.HTTPFlow, websocket.WebSocketFlow)
+    @only(http.HTTPFlow)
     def __call__(self, f):
-        if isinstance(f, websocket.WebSocketFlow):
-            f = f.handshake_flow
         return bool(
             self.re.search(f.request.host) or
             self.re.search(f.request.pretty_host)
@@ -345,10 +350,8 @@ class FUrl(_Rex):
             toks = toks[1:]
         return klass(*toks)
 
-    @only(http.HTTPFlow, websocket.WebSocketFlow)
+    @only(http.HTTPFlow)
     def __call__(self, f):
-        if isinstance(f, websocket.WebSocketFlow):
-            f = f.handshake_flow
         if not f or not f.request:
             return False
         return self.re.search(f.request.pretty_url)
@@ -360,10 +363,10 @@ class FSrc(_Rex):
     is_binary = False
 
     def __call__(self, f):
-        if not f.client_conn or not f.client_conn.address:
+        if not f.client_conn or not f.client_conn.peername:
             return False
-        r = "{}:{}".format(f.client_conn.address[0], f.client_conn.address[1])
-        return f.client_conn.address and self.re.search(r)
+        r = "{}:{}".format(f.client_conn.peername[0], f.client_conn.peername[1])
+        return f.client_conn.peername and self.re.search(r)
 
 
 class FDst(_Rex):
@@ -378,6 +381,60 @@ class FDst(_Rex):
         return f.server_conn.address and self.re.search(r)
 
 
+class FReplay(_Action):
+    code = "replay"
+    help = "Match replayed flows"
+
+    def __call__(self, f):
+        return f.is_replay is not None
+
+
+class FReplayClient(_Action):
+    code = "replayq"
+    help = "Match replayed client request"
+
+    def __call__(self, f):
+        return f.is_replay == 'request'
+
+
+class FReplayServer(_Action):
+    code = "replays"
+    help = "Match replayed server response"
+
+    def __call__(self, f):
+        return f.is_replay == 'response'
+
+
+class FMeta(_Rex):
+    code = "meta"
+    help = "Flow metadata"
+    flags = re.MULTILINE
+    is_binary = False
+
+    def __call__(self, f):
+        m = "\n".join([f"{key}: {value}" for key, value in f.metadata.items()])
+        return self.re.search(m)
+
+
+class FMarker(_Rex):
+    code = "marker"
+    help = "Match marked flows with specified marker"
+    is_binary = False
+
+    def __call__(self, f):
+        return self.re.search(f.marked)
+
+
+class FComment(_Rex):
+    code = "comment"
+    help = "Flow comment"
+    flags = re.MULTILINE
+    is_binary = False
+
+    def __call__(self, f):
+        return self.re.search(f.comment)
+
+
 class _Int(_Action):
 
     def __init__(self, num):
@@ -440,6 +497,9 @@ filter_unary: Sequence[Type[_Action]] = [
     FErr,
     FHTTP,
     FMarked,
+    FReplay,
+    FReplayClient,
+    FReplayServer,
     FReq,
     FResp,
     FTCP,
@@ -460,6 +520,9 @@ filter_rex: Sequence[Type[_Rex]] = [
     FMethod,
     FSrc,
     FUrl,
+    FMeta,
+    FMarker,
+    FComment,
 ]
 filter_int = [
     FCode
@@ -480,9 +543,9 @@ def _make():
     unicode_words = pp.CharsNotIn("()~'\"" + pp.ParserElement.DEFAULT_WHITE_CHARS)
     unicode_words.skipWhitespace = True
     regex = (
-            unicode_words
-            | pp.QuotedString('"', escChar='\\')
-            | pp.QuotedString("'", escChar='\\')
+        unicode_words
+        | pp.QuotedString('"', escChar='\\')
+        | pp.QuotedString("'", escChar='\\')
     )
     for cls in filter_rex:
         f = pp.Literal(f"~{cls.code}") + pp.WordEnd() + regex.copy()
